

standard_blues = [(0, ["Idom7", "Idom7", "Idom7", "Idom7",
		      "IVdom7", "IVdom7", "Idom7", "Idom7",
		      "Vdom7", "IVdom7", "Idom7", "V7"]),
		  (1, 'R')]

standard_blues2 = [(0, ["Idom7", "IVdom7", "Idom7", "Idom7",
		      "IVdom7", "IVdom7", "Idom7", "Idom7",
		      "Vdom7", "IVdom7", "Idom7", "V7"]),
		  (1, 'R')]


jazzy_blues = [(0, ["I13", "IV11", "III7", "Idom7",
		    "IVdom7", "IVdim7", "I13", "VI7",
		    "IIm7", "V7#9", "I7", "V7#9"]),
		  (1, 'R')]
